@@ -18,6 +18,7 @@
 
 #include <kdebug.h>
 #include <kfileitem.h>
+#include <kiconloader.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kstandarddirs.h>
@@ -85,7 +86,7 @@ DccTransferRecv::DccTransferRecv( DccPanel* panel, const QString& partnerNick, c
     m_fileURL.adjustPath( 1 );
     // Append folder with partner's name if wanted
     if ( Preferences::dccCreateFolder() )
-        m_fileURL.addPath( m_partnerNick.lower() + "/" );
+        m_fileURL.addPath( m_partnerNick + '/' );
 
     if (!kapp->authorize("allow_downloading"))
     {
@@ -107,7 +108,7 @@ DccTransferRecv::DccTransferRecv( DccPanel* panel, const QString& partnerNick, c
 
     // Append partner's name to file name if wanted
     if ( Preferences::dccAddPartner() )
-        m_fileURL.addPath( m_partnerNick.lower() + "." + fileNameTmp );
+        m_fileURL.addPath( m_partnerNick + '.' + fileNameTmp );
     else
         m_fileURL.addPath( fileNameTmp );
 
@@ -139,6 +140,16 @@ DccTransferRecv::~DccTransferRecv()
     cleanUp();
 }
 
+QString DccTransferRecv::getTypeText() const
+{
+    return i18n( "Receive" );
+}
+
+QPixmap DccTransferRecv::getTypeIcon() const
+{
+    return KGlobal::iconLoader()->loadIcon( "down", KIcon::Small );
+}
+
 void DccTransferRecv::cleanUp()
 {
     kdDebug() << "DccTransferRecv::cleanUp()" << endl;
@@ -167,7 +178,7 @@ void DccTransferRecv::failed( const QString& errorMessage )
     setStatus( Failed, errorMessage );
     updateView();
     cleanUp();
-    emit done( m_fileURL.path(), Failed, errorMessage );
+    emit done( this );
 
     if ( bNeedToOpenDetail )
         openDetailDialog();
@@ -185,7 +196,7 @@ void DccTransferRecv::abort()                     // public slot
     setStatus( Aborted );
     updateView();
     cleanUp();
-    emit done( m_fileURL.path(), Aborted );
+    emit done( this );
 }
 
 void DccTransferRecv::start()                     // public slot
@@ -295,17 +306,29 @@ void DccTransferRecv::slotLocalCanResume( KIO::Job* job, KIO::filesize_t size )
         disconnect( transferJob, 0, 0, 0 );
         transferJob->kill();
 
-        if ( Preferences::dccAutoResume() )
+        if ( m_panel->isLocalFileInWritingProcess( m_fileURL ) )
+        {
+            askAndPrepareLocalKio( i18n( "<b>The file is used by another transfer.</b><br>"
+                "%1<br>" )
+                .arg( m_fileURL.prettyURL() ),
+                DccResumeDialog::RA_Rename | DccResumeDialog::RA_Cancel,
+                DccResumeDialog::RA_Rename );
+        }
+        else if ( Preferences::dccAutoResume() )
+        {
             prepareLocalKio( false, true, size );
+        }
         else
+        {
             askAndPrepareLocalKio( i18n( "<b>A partial file exists.</b><br>"
                 "%1<br>"
                 "Size of the partial file: %2 bytes<br>" )
                 .arg( m_fileURL.prettyURL() )
-                .arg( DccTransfer::getPrettyNumberText( QString::number( size ) ) ),
+                .arg( KGlobal::locale()->formatNumber( size, 0 ) ),
                 DccResumeDialog::RA_Resume | DccResumeDialog::RA_Overwrite | DccResumeDialog::RA_Rename | DccResumeDialog::RA_Cancel,
                 DccResumeDialog::RA_Resume,
                 size );
+        }
     }
 
     kdDebug() << "DccTransferRecv::slotLocalCanResume() [END]" << endl;
@@ -489,7 +512,7 @@ void DccTransferRecv::slotLocalWriteDone()        // <-WriteCacheHandler::done()
     setStatus( Done );
     updateView();
     cleanUp();
-    emit done( m_fileURL.fileName() );
+    emit done( this );
 }
 
                                                   // <- WriteCacheHandler::gotError()
@@ -616,7 +639,7 @@ void DccTransferRecvWriteCacheHandler::slotKIODataReq( KIO::Job*, QByteArray& da
         m_writeReady = true;
     else
     {
-        // No more data left to read from incomming dcctransfer
+        // No more data left to read from incoming dcctransfer
         if ( !m_cacheList.isEmpty() )
         {
             // once we write everything in cache, the file is complete.
