@@ -1,5 +1,3 @@
-// -*- mode: c++; c-file-style: "bsd"; c-basic-offset: 4; tabs-width: 4; indent-tabs-mode: nil -*-
-
 /*
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -8,10 +6,9 @@
 */
 
 /*
-    begin:      Fri Jan 25 2002
-    copyright:  (C) 2002 by Dario Abatianni
-                (C) 2004 by Peter Simonsson
-    email:      eisfuchs@tigress.com
+  Copyright (C) 2002 Dario Abatianni <eisfuchs@tigress.com>
+  Copyright (C) 2004 Peter Simonsson <psn@linux.se>
+  Copyright (C) 2006 Eike Hein <sho@eikehein.com>
 */
 
 #include <qdatastream.h>
@@ -42,6 +39,7 @@
 
 InputFilter::InputFilter()
 {
+    m_connecting = false;
 }
 
 InputFilter::~InputFilter()
@@ -143,6 +141,7 @@ void InputFilter::parseClientCommand(const QString &prefix, const QString &comma
 
             QString ctcpCommand=ctcp.left(ctcp.find(" ")).lower();
             QString ctcpArgument=ctcp.mid(ctcp.find(" ")+1);
+            ctcpArgument=static_cast<KonversationApplication*>(kapp)->doAutoreplace(ctcpArgument,false);
 
             // If it was a ctcp action, build an action string
             if(ctcpCommand=="action" && isChan)
@@ -241,9 +240,8 @@ void InputFilter::parseClientCommand(const QString &prefix, const QString &comma
                     else
                     {
                         // Do not internationalize the below version string
-                        reply = QString("Konversation %1 Build %2 (C) 2002-2006 by the Konversation team")
-                            .arg(QString(KONVI_VERSION))
-                            .arg(QString::number(COMMIT));
+                        reply = QString("Konversation %1 (C) 2002-2006 by the Konversation team")
+                            .arg(QString(KONVI_VERSION));
                     }
                     server->ctcpReply(sourceNick,"VERSION "+reply);
                 }
@@ -255,28 +253,42 @@ void InputFilter::parseClientCommand(const QString &prefix, const QString &comma
                 {
                     // Extract DCC type and argument list
                     QString dccType=ctcpArgument.lower().section(' ',0,0);
-                    QStringList dccArgument=QStringList::split(' ',ctcpArgument.mid(ctcpArgument.find(" ")+1).lower());
+
+                    // Support file names with spaces
+                    QString dccArguments = ctcpArgument.mid(ctcpArgument.find(" ")+1);
+                    QStringList dccArgumentList;
+
+                    if ((dccArguments.contains('\"') >= 2) && (dccArguments.startsWith("\""))) {
+                        int lastQuotePos = dccArguments.findRev("\"");
+                        if (dccArguments[lastQuotePos+1] == ' ') {
+                            QString fileName = dccArguments.mid(1, lastQuotePos-1);
+                            dccArguments = dccArguments.mid(lastQuotePos+2);
+
+                            dccArgumentList.append(fileName);
+                        }
+                    }
+                    dccArgumentList += QStringList::split(' ', dccArguments);
 
                     // Incoming file?
                     if(dccType=="send")
                     {
                         konv_app->notificationHandler()->dccIncoming(server->getStatusView(), sourceNick);
-                        emit addDccGet(sourceNick,dccArgument);
+                        emit addDccGet(sourceNick,dccArgumentList);
                     }
                     // Incoming file that shall be resumed?
                     else if(dccType=="accept")
                     {
-                        emit resumeDccGetTransfer(sourceNick,dccArgument);
+                        emit resumeDccGetTransfer(sourceNick,dccArgumentList);
                     }
                     // Remote client wants our sent file resumed
                     else if(dccType=="resume")
                     {
-                        emit resumeDccSendTransfer(sourceNick,dccArgument);
+                        emit resumeDccSendTransfer(sourceNick,dccArgumentList);
                     }
                     else if(dccType=="chat")
                     {
                         // will be connected via Server to KonversationMainWindow::addDccChat()
-                        emit addDccChat(server->getNickname(),sourceNick,server->getNumericalIp(),dccArgument,false);
+                        emit addDccChat(server->getNickname(),sourceNick,server->getNumericalIp(),dccArgumentList,false);
                     }
                     else
                     {
@@ -327,6 +339,7 @@ void InputFilter::parseClientCommand(const QString &prefix, const QString &comma
         // No CTCP, so it's an ordinary channel or query message
         else
         {
+            trailing=static_cast<KonversationApplication*>(kapp)->doAutoreplace(trailing,false);
             if (isChan)
             {
                 if(!isIgnore(prefix,Ignore::Channel))
@@ -430,18 +443,16 @@ void InputFilter::parseClientCommand(const QString &prefix, const QString &comma
                 // No, so it was a normal notice
                 else
                 {
-                    if(server->identifyMsg())
-                    {
-                        trailing = trailing.mid(1);
-                    }
-
                     // Nickserv
-                    if(trailing.startsWith("If this is your nick"))
+                    if (trailing.startsWith("If this is your nick"))
                     {
                         // Identify command if specified
                         server->registerWithServices();
                     }
-                    else if(trailing.lower() == "password accepted - you are now recognized"
+                    else if (server->identifyMsg())
+                        trailing = trailing.mid(1);
+
+                    if(trailing.lower() == "password accepted - you are now recognized"
                         || trailing.lower() == "you have already identified")
                     {
                         NickInfoPtr nickInfo = server->getNickInfo(server->getNickname());
@@ -458,9 +469,7 @@ void InputFilter::parseClientCommand(const QString &prefix, const QString &comma
         QString channelName(trailing);
         // Sometimes JOIN comes without ":" in front of the channel name
         if(channelName.isEmpty())
-        {
             channelName=parameterList[parameterList.count()-1];
-        }
 
         // Did we join the channel, or was it someone else?
         if(server->isNickname(sourceNick))
@@ -476,14 +485,25 @@ void InputFilter::parseClientCommand(const QString &prefix, const QString &comma
                     channelName=channelName.section(' ',0,0);
                 }
             */
+
             // Join the channel
             server->joinChannel(channelName, sourceHostmask);
-            server->getChannelByName(channelName)->clearModeList();
-            // Request modes for the channel
-            server->queue("MODE "+channelName);
+
+            server->resetNickList(channelName);
+
             // Upon JOIN we're going to receive some NAMES input from the server which
             // we need to be able to tell apart from manual invocations of /names
             setAutomaticRequest("NAMES",channelName,true);
+
+            server->getChannelByName(channelName)->clearModeList();
+
+            // Request modes for the channel
+            server->queue("MODE "+channelName);
+
+            // Initiate channel ban list
+            server->getChannelByName(channelName)->clearBanList();
+            setAutomaticRequest("BANLIST",channelName,true);
+            server->queue("MODE "+channelName+" +b");
         }
         else
         {
@@ -497,10 +517,30 @@ void InputFilter::parseClientCommand(const QString &prefix, const QString &comma
     }
     else if(command=="part")
     {
-        Channel* channel = server->removeNickFromChannel(parameterList[0],sourceNick,trailing);
+        /* FIXME: Ugly workaround for a version of the PART line encountered on ircu:
+         *   :Nick!user@host PART :#channel
+         * Quote: "The final colon is specified as a "last argument" designator, and
+         * is always valid before the final argument."
+         */
+
+        QString channel;
+        QString reason;
+
+        if (parameterList[0].isEmpty())
+        {
+            channel = trailing;
+        }
+        else
+        {
+            channel = parameterList[0];
+            reason = trailing;
+        }
+
+        Channel* channelPtr = server->removeNickFromChannel(channel,sourceNick,reason);
+
         if(sourceNick != server->getNickname())
         {
-            konv_app->notificationHandler()->part(channel, sourceNick);
+            konv_app->notificationHandler()->part(channelPtr, sourceNick);
         }
     }
     else if(command=="quit")
@@ -513,10 +553,17 @@ void InputFilter::parseClientCommand(const QString &prefix, const QString &comma
     }
     else if(command=="nick")
     {
-        server->renameNick(sourceNick,trailing);
-        if(sourceNick != server->getNickname())
+        QString newNick(trailing);
+
+        // Message may not include ":" in front of the new nickname
+        if (newNick.isEmpty())
+            newNick=parameterList[parameterList.count()-1];
+
+        server->renameNick(sourceNick,newNick);
+
+        if (sourceNick != server->getNickname())
         {
-            konv_app->notificationHandler()->nickChange(server->getStatusView(), sourceNick, trailing);
+            konv_app->notificationHandler()->nickChange(server->getStatusView(), sourceNick, newNick);
         }
     }
     else if(command=="topic")
@@ -542,16 +589,17 @@ void InputFilter::parseClientCommand(const QString &prefix, const QString &comma
     }
     else
     {
-        server->appendMessageToFrontmost(command,parameterList.join(" ")+" "+trailing);
+        server->appendMessageToFrontmost(command,parameterList.join(" ")+' '+trailing);
     }
 }
 
 void InputFilter::parseServerCommand(const QString &prefix, const QString &command, const QStringList &parameterList, const QString &trailing)
 {
     bool isNumeric;
-    int numeric;
-    numeric=command.toInt(&isNumeric);
+    int numeric = command.toInt(&isNumeric);
+
     Q_ASSERT(server); if(!server) return;
+
     if(!isNumeric)
     {
         if(command=="ping")
@@ -578,15 +626,11 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
         }
         else if(command=="pong")
         {
-            // Since we use PONG replys to measure lag, too, we check, if this PONG was
-            // due to Lag measures and tell the notify system about it. We use "###" as
-            // response, because this couldn't be a 303 reply, so it must be a PONG reply
-
             // double check if we are in lag measuring mode since some servers fail to send
             // the LAG cookie back in PONG
-            if(trailing=="LAG" || getLagMeasuring())
+            if(trailing.startsWith("LAG") || getLagMeasuring())
             {
-                emit notifyResponse("###");
+                server->pongReceived();
             }
         }
         else if(command=="mode")
@@ -600,7 +644,7 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
         // All yet unknown messages go into the frontmost window unaltered
         else
         {
-            server->appendMessageToFrontmost(command,parameterList.join(" ")+" "+trailing);
+            server->appendMessageToFrontmost(command,parameterList.join(" ")+' '+trailing);
         }
     }
     else
@@ -614,19 +658,20 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
                 if(numeric==RPL_WELCOME)
                 {
                     QString host;
+
                     if(trailing.contains("@"))
-                    {
                         host = trailing.section("@",1);
-                    }
+
                     // re-set nickname, since the server may have truncated it
                     if(parameterList[0]!=server->getNickname())
-                    {
                         server->renameNick(server->getNickname(), parameterList[0]);
-                    }
+
                     // Remember server's insternal name
                     server->setIrcName(prefix);
+
                     // Send the welcome signal, so the server class knows we are connected properly
                     emit welcome(host);
+                    m_connecting = true;
                 }
                 server->appendStatusMessage(i18n("Welcome"),trailing);
                 break;
@@ -668,7 +713,6 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
                     else
                     {
                         property = *it;
-                        // value = "";
                     }
                     if (property=="PREFIX")
                     {
@@ -676,7 +720,7 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
                         if(pos==-1)
                         {
                             server->setPrefixes (QString::null, value);
-                                                  // XXX if ) isn't in the string, NOTHING should be there. anyone got a server
+                            // XXX if ) isn't in the string, NOTHING should be there. anyone got a server
                             if (value.length() || property.length())
                                 server->appendStatusMessage("","XXX Server sent bad PREFIX in RPL_ISUPPORT, please report.");
                         }
@@ -691,7 +735,8 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
                     }
                     else if (property == "CAPAB")
                     {
-                        server->queue("CAPAB IDENTIFY-MSG");
+                        // Disable as we don't use this for anything yet
+                        //server->queue("CAPAB IDENTIFY-MSG");
                     }
                     else
                     {
@@ -731,7 +776,7 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
                         else if(mode=='k')
                         {
                             parameter=parameterList[parameterCount++];
-                            message += " " + parameter;
+                            message += ' ' + parameter;
                             modesAre+=i18n("password protected");
                         }
                         else if(mode=='a')
@@ -743,7 +788,7 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
                         else if(mode=='l')
                         {
                             parameter=parameterList[parameterCount++];
-                            message += " " + parameter;
+                            message += ' ' + parameter;
                             modesAre+=i18n("limited to %n user", "limited to %n users", parameter.toInt());
                         }
                         else
@@ -784,14 +829,28 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
             }
             case RPL_NAMREPLY:
             {
-                // Display message only if this was not an automatic request.
-                if(getAutomaticRequest("NAMES",parameterList[2])==1)
+                QStringList nickList;
+
+                if(!trailing.isEmpty())
                 {
-                    QStringList nickList = QStringList::split(" ", trailing);
-                    // send list to channel
-                    server->addPendingNickList(parameterList[2], nickList);
+                    nickList = QStringList::split(" ", trailing);
+                }
+                else if(parameterList.count() > 3)
+                {
+                    for(uint i = 3; i < parameterList.count(); i++) {
+                        nickList.append(parameterList[i]);
+                    }
                 }
                 else
+                {
+                    kdDebug() << "Hmm seems something is broken... can't get to the names!" << endl;
+                }
+
+                // send list to channel
+                server->addPendingNickList(parameterList[2], nickList);
+
+                // Display message only if this was not an automatic request.
+                if(!getAutomaticRequest("NAMES",parameterList[2])==1)
                 {
                     server->appendMessageToFrontmost(i18n("Names"),trailing);
                 }
@@ -801,8 +860,6 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
             {
                 if(getAutomaticRequest("NAMES",parameterList[1])==1)
                 {
-                    // tell the channel that the list of nicks is complete
-                    server->noMorePendingNicks(parameterList[1]);
                     // This code path was taken for the automatic NAMES input on JOIN, upcoming
                     // NAMES input for this channel will be manual invocations of /names
                     setAutomaticRequest("NAMES",parameterList[1],false);
@@ -816,7 +873,7 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
             // Topic set messages
             case RPL_NOTOPIC:
             {
-                server->appendMessageToFrontmost(i18n("TOPIC"),i18n("The channel %1 has no topic set.").arg(parameterList[1]).arg(parameterList[2]));
+                server->appendMessageToFrontmost(i18n("TOPIC"),i18n("The channel %1 has no topic set.").arg(parameterList[1]) /*.arg(parameterList[2])*/); //FIXME ok, whats the second parameter supposed to be?
 
                 break;
             }
@@ -906,15 +963,24 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
                 }
                 else                              // not connected yet, so try to find a nick that's not in use
                 {
-                    // Get the next nick from the list
-                    QString newNick=server->getNextNickname();
-                    // Update Server window
-                    server->obtainNickInfo(server->getNickname()) ;
-                    server->renameNick(server->getNickname(), newNick);
-                    // Show message
-                    server->appendMessageToFrontmost(i18n("Nick"),i18n("Nickname already in use. Trying %1.").arg(newNick));
-                    // Send nickchange request to the server
-                    server->queue("NICK "+newNick);
+                    // Get the next nick from the list or ask for a new one
+                    QString newNick = server->getNextNickname();
+
+                    // The user chose to disconnect
+                    if (newNick.isNull())
+                    {
+                        server->disconnect();
+                    }
+                    else
+                    {
+                        // Update Server window
+                        server->obtainNickInfo(server->getNickname()) ;
+                        server->renameNick(server->getNickname(), newNick);
+                        // Show message
+                        server->appendMessageToFrontmost(i18n("Nick"), i18n("Nickname already in use. Trying %1.").arg(newNick));
+                        // Send nickchange request to the server
+                        server->queue("NICK "+newNick);
+                    }
                 }
                 break;
             }
@@ -927,10 +993,19 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
                 else                              // Find a new nick as in ERR_NICKNAMEINUSE
                 {
                     QString newNick = server->getNextNickname();
-                    server->obtainNickInfo(server->getNickname()) ;
-                    server->renameNick(server->getNickname(), newNick);
-                    server->appendMessageToFrontmost(i18n("Nick"), i18n("Erroneus nickname. Changing nick to %1." ).arg(newNick)) ;
-                    server->queue("NICK "+newNick);
+
+                    // The user chose to disconnect
+                    if (newNick.isNull())
+                    {
+                        server->disconnect();
+                    }
+                    else
+                    {
+                        server->obtainNickInfo(server->getNickname()) ;
+                        server->renameNick(server->getNickname(), newNick);
+                        server->appendMessageToFrontmost(i18n("Nick"), i18n("Erroneus nickname. Changing nick to %1." ).arg(newNick)) ;
+                        server->queue("NICK "+newNick);
+                    }
                 }
                 break;
             }
@@ -942,33 +1017,33 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
             }
             case RPL_MOTDSTART:
             {
-                if(!Preferences::skipMOTD())
+                if(!m_connecting || !Preferences::skipMOTD())
                   server->appendStatusMessage(i18n("MOTD"),i18n("Message of the day:"));
                 break;
             }
             case RPL_MOTD:
             {
-                if(!Preferences::skipMOTD())
-                  server->appendStatusMessage(i18n("MOTD"),trailing);
+                if(!m_connecting || !Preferences::skipMOTD())
+                    server->appendStatusMessage(i18n("MOTD"),trailing);
                 break;
             }
             case RPL_ENDOFMOTD:
             {
-                if(!Preferences::skipMOTD())
-                  server->appendStatusMessage(i18n("MOTD"),i18n("End of message of the day"));
-                // Autojoin (for now this must be enough)
-                if(server->getAutoJoin())
-                {
-                    server->queue(server->getAutoJoinCommand());
-                }
+                if(!m_connecting || !Preferences::skipMOTD())
+                    server->appendStatusMessage(i18n("MOTD"),i18n("End of message of the day"));
+
+                if(m_connecting)
+                    server->autoCommandsAndChannels();
+
+                m_connecting = false;
                 break;
             }
             case ERR_NOMOTD:
             {
-                if(server->getAutoJoin())
-                {
-                    server->queue(server->getAutoJoinCommand());
-                }
+                if(m_connecting)
+                    server->autoCommandsAndChannels();
+
+                m_connecting = false;
                 break;
             }
             case RPL_YOUREOPER:
@@ -1045,12 +1120,15 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
                 // Display message only if this was not an automatic request.
                 if(getAutomaticRequest("WHOIS",parameterList[1])==0)
                 {
+                    // escape html tags
+                    QString escapedRealName(trailing);
+                    escapedRealName.replace("<","&lt;").replace(">","&gt;");
                     server->appendMessageToFrontmost(i18n("Whois"),
-                        i18n("%1 is %2&#64;%3 (%4)")
-                        .arg(parameterList[1])    // Use &#64; instead of @
-                        .arg(parameterList[2])    // to avoid parsing as email
+                        i18n("%1 is %2@%3 (%4)")
+                        .arg(parameterList[1])
+                        .arg(parameterList[2])
                         .arg(parameterList[3])
-                        .arg(trailing));
+                        .arg(escapedRealName), false);   // Don't parse any urls
                 }
                 else
                 {
@@ -1095,7 +1173,7 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
                 if(getAutomaticRequest("WHOIS",parameterList[1])==0)
                 {
                     // Prints "psn is an identified user"
-                    //server->appendStatusMessage(i18n("Whois"),parameterList.join(" ").section(' ',1)+" "+trailing);
+                    //server->appendStatusMessage(i18n("Whois"),parameterList.join(" ").section(' ',1)+' '+trailing);
                     // The above line works fine, but can't be i18n'ised. So use the below instead.. I hope this is okay.
                     server->appendMessageToFrontmost(i18n("Whois"), i18n("%1 is an identified user.").arg(parameterList[1]));
                 }
@@ -1127,13 +1205,12 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
                     if(getAutomaticRequest("WHO",whoRequestList.front())==0)
                     {
                         server->appendMessageToFrontmost(i18n("Who"),
-                                                  // Use &#64; instead of @
-                            i18n("%1 is %2&#64;%3 (%4)%5").arg(parameterList[5])
+                            i18n("%1 is %2@%3 (%4)%5").arg(parameterList[5])
                             .arg(parameterList[2])
                             .arg(parameterList[3])
                             .arg(trailing.section(" ", 1))
                             .arg(bAway?i18n(" (Away)"):QString::null)
-                            );
+                            , false); // Don't parse as url
                     }
                 }
                 break;
@@ -1186,13 +1263,13 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
                 for(unsigned int index=0; index < channelList.count(); index++)
                 {
                     QString lookChannel=channelList[index];
-                    if(lookChannel.startsWith("*"))
+                    if(lookChannel.startsWith("*") || lookChannel.startsWith("&"))
                     {
                         adminChannels.append(lookChannel.mid(1));
                         server->setChannelNick(lookChannel.mid(1), parameterList[1], 16);
                     }
                                                   // See bug #97354 part 2
-                    else if(lookChannel.startsWith("!") && server->isAChannel(lookChannel.mid(1)))
+                    else if((lookChannel.startsWith("!") || lookChannel.startsWith("~")) && server->isAChannel(lookChannel.mid(1)))
                     {
                         ownerChannels.append(lookChannel.mid(1));
                         server->setChannelNick(lookChannel.mid(1), parameterList[1], 8);
@@ -1456,7 +1533,7 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
                     if(getAutomaticRequest("USERHOST",nick)==0)
                     {
                         server->appendMessageToFrontmost(i18n("Userhost"),
-                            i18n("%1%2 is %3%4.")
+                            i18n("%1 = nick, %2 = shows if nick is op, %3 = hostmask, %4 = shows away", "%1%2 is %3%4.")
                             .arg(nick)
                             .arg((ircOp) ? i18n(" (IRC Operator)") : QString::null)
                             .arg(mask)
@@ -1510,19 +1587,9 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
             case RPL_NOWAWAY:
             {
                 NickInfo* nickInfo = server->getNickInfo(parameterList[0]);
-                if(nickInfo)
-                {
-                    nickInfo->setAway(true);
-                }
-                if(!server->isAway())
-                {
-                    server->appendMessageToFrontmost(i18n("Away"),i18n("You are now marked as being away."));
-                    emit away();
-                }
-                else
-                {
-                    server->appendMessageToFrontmost(i18n("Away"),i18n("You are marked as being away."));
-                }
+                if (nickInfo) nickInfo->setAway(true);
+                server->appendMessageToFrontmost(i18n("Away"),i18n("You are now marked as being away."));
+                if (!server->isAway()) emit away();
                 break;
             }
             case RPL_UNAWAY:
@@ -1553,6 +1620,29 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
 
                 break;
             }
+            case RPL_BANLIST:
+            {
+                if (getAutomaticRequest("BANLIST", parameterList[1]))
+                {
+                    server->addBan(parameterList[1], parameterList.join(" ").section(' ', 2, 4));
+                } else {
+                    QDateTime when;
+                    when.setTime_t(parameterList[4].toUInt());
+
+                    server->appendMessageToFrontmost(i18n("BanList:%1").arg(parameterList[1]), i18n("BanList message: e.g. *!*@aol.com set by MrGrim on <date>", "%1 set by %2 on %3").arg(parameterList[2]).arg(parameterList[3].section('!', 0, 0)).arg(when.toString(Qt::LocalDate)));
+                }
+                break;
+            }
+            case RPL_ENDOFBANLIST:
+            {
+                if (getAutomaticRequest("BANLIST", parameterList[1]))
+                {
+                    setAutomaticRequest("BANLIST", parameterList[1], false);
+                } else {
+                    server->appendMessageToFrontmost(i18n("BanList:%1").arg(parameterList[1]), i18n("End of Ban List."));
+                }
+                break;
+            }
             case ERR_NOCHANMODES:
             {
                 ChatWindow *chatwindow = server->getChannelByName(parameterList[1]);
@@ -1567,10 +1657,11 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
                 break;
             }
             case ERR_NOSUCHSERVER:
-            {                                     //Some servers don't know their name, so they return an error instead of the PING data
+            {
+                //Some servers don't know their name, so they return an error instead of the PING data
                 if (getLagMeasuring() && trailing.startsWith(prefix))
                 {
-                    emit notifyResponse("###");
+                    server->pongReceived();
                 }
                 break;
             }
@@ -1587,15 +1678,7 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
             case RPL_LUSERCHANNELS:
             case RPL_LUSERME:
             {
-                server->appendStatusMessage(i18n("Users"), parameterList.join(" ").section(' ',1) + " "+trailing);
-                break;
-            }
-            case RPL_CAPAB: // Special freenode reply afaik
-            {
-                if(trailing.contains("IDENTIFY-MSG"))
-                {
-                    server->enableIdentifyMsg(true);
-                }
+                server->appendStatusMessage(i18n("Users"), parameterList.join(" ").section(' ',1) + ' '+trailing);
                 break;
             }
             case ERR_UNKNOWNCOMMAND:
@@ -1616,12 +1699,23 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
 
                 break;
             }
+            case RPL_CAPAB: // Special freenode reply afaik
+            {
+                // Disable as we don't use this for anything yet
+                if(trailing.contains("IDENTIFY-MSG"))
+                {
+                    server->enableIdentifyMsg(true);
+                    break;
+                }
+
+            /* don't break; - this is also used as RPL_DATASTR on ircu and some others */
+            }
             // FALLTHROUGH to default to let the error display otherwise
             default:
             {
                 // All yet unknown messages go into the frontmost window without the
                 // preceding nickname
-                server->appendMessageToFrontmost(command, parameterList.join(" ").section(' ',1) + " "+trailing);
+                server->appendMessageToFrontmost(command, parameterList.join(" ").section(' ',1) + ' '+trailing);
             }
         }                                         // end of numeric switch
     }
@@ -1659,7 +1753,7 @@ void InputFilter::parseModes(const QString &sourceNick, const QStringList &param
                 {
                     // Remember the mode parameter
                     parameter=parameterList[2+parameterIndex];
-                    message += " " + parameter;
+                    message += ' ' + parameter;
                     // Switch to next parameter
                     ++parameterIndex;
                 }
@@ -1693,22 +1787,18 @@ bool InputFilter::isAChannel(const QString &check)
 
 bool InputFilter::isIgnore(const QString &sender, Ignore::Type type)
 {
-    bool doIgnore=false;
+    bool doIgnore = false;
 
-    QPtrList<Ignore> list=Preferences::ignoreList();
+    QPtrList<Ignore> list = Preferences::ignoreList();
 
-    for(unsigned int index=0;index<list.count();index++)
+    for(unsigned int index =0; index<list.count(); index++)
     {
-        Ignore* item=list.at(index);
-        QRegExp ignoreItem(item->getName(),false,true);
-        if(ignoreItem.exactMatch(sender) && (item->getFlags() & type))
-        {
-            doIgnore=true;
-        }
-        if(ignoreItem.exactMatch(sender) && (item->getFlags() & Ignore::Exception))
-        {
+        Ignore* item = list.at(index);
+        QRegExp ignoreItem(QRegExp::escape(item->getName()).replace("\\*", "(.*)"),false);
+        if (ignoreItem.exactMatch(sender) && (item->getFlags() & type))
+            doIgnore = true;
+        if (ignoreItem.exactMatch(sender) && (item->getFlags() & Ignore::Exception))
             return false;
-        }
     }
 
     return doIgnore;
