@@ -6,9 +6,9 @@
 */
 
 /*
-  begin:     Fri Jan 25 2002
-  copyright: (C) 2002 by Dario Abatianni
-  email:     eisfuchs@tigress.com
+  Copyright (C) 2002 Dario Abatianni <eisfuchs@tigress.com>
+  Copyright (C) 2004 Peter Simonsson <psn@linux.se>
+  Copyright (C) 2006 Eike Hein <sho@eikehein.com>
 */
 
 #ifndef INPUTFILTER_H
@@ -31,7 +31,7 @@ class InputFilter : public QObject
 {
     Q_OBJECT
 
-        public:
+    public:
         InputFilter();
         ~InputFilter();
 
@@ -49,7 +49,7 @@ class InputFilter : public QObject
         void setLagMeasuring(bool yes);
         bool getLagMeasuring();
 
-        signals:
+    signals:
         void welcome(const QString& ownHost);
         void notifyResponse(const QString &nicksOnline);
                                                   // will be connected to Server::addDccGet()
@@ -68,7 +68,7 @@ class InputFilter : public QObject
         void invitation(const QString& nick,const QString& channel);
         void away();
         void unAway();
-        // will be connected via Server to KonversationMainWindow::addDccChat()
+
         void addDccChat(const QString& myNick,const QString& nick,const QString& numericalIp,const QStringList& arguments,bool listen);
 
     protected:
@@ -89,5 +89,8 @@ class InputFilter : public QObject
 
         QStringList newNickList;
         int m_debugCount;
+
+        /// Used when handling MOTD
+        bool m_connecting;
 };
 #endif
