@@ -40,7 +40,7 @@ IRCInput::IRCInput(QWidget* parent) : KTextEdit(parent)
 {
     m_lastHeight=document()->height();
 
-    //i'm not terribly interested in finding out where this value comes from
+    //I am not terribly interested in finding out where this value comes from
     //nor in compensating for it if my guess is incorrect. so, cache it.
     m_qtBoxPadding=m_lastHeight-fontMetrics().lineSpacing();
 
@@ -150,7 +150,7 @@ QSize IRCInput::sizeHint() const
 
     int ObscurePadding = 4;
     int f=2*frameWidth();
-    int w=12 * (QMAX(fontMetrics().lineSpacing(),14) + f + ObscurePadding);
+    int w=12 * (kMax(fontMetrics().lineSpacing(),14) + f + ObscurePadding);
     int h=m_lastHeight - m_qtBoxPadding + f + ObscurePadding;
     return QSize(w,h);
 }
@@ -177,7 +177,7 @@ QString IRCInput::text() const
         QDomElement node=nodes.item(0).toElement();
         return node.text();
     }
-    return QString::null;
+    return QString();
 
     #else
     return KTextEdit::text();
