@@ -6,8 +6,9 @@
 */
 
 /*
-  copyright: (C) 2004 by Peter Simonsson <psn@linux.se>
+  Copyright (C) 2004 Peter Simonsson <psn@linux.se>
 */
+
 #ifndef KONVERSATIONJOINCHANNELDIALOG_H
 #define KONVERSATIONJOINCHANNELDIALOG_H
 
@@ -24,7 +25,7 @@ namespace Konversation
     {
         Q_OBJECT
             public:
-            JoinChannelDialog(Server* server, QWidget *parent = 0, const char *name = 0);
+            explicit JoinChannelDialog(Server* server, QWidget *parent = 0, const char *name = 0);
             ~JoinChannelDialog();
 
             QString channel() const;
