@@ -1,5 +1,13 @@
+/*
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
+*/
 
-// (C)2003 Mickael Marchand <marchand@kde.org>
+/*
+  Copyright (C) 2003 Mickael Marchand <marchand@kde.org>
+*/
 
 #include <kdebug.h>
 #include <klibloader.h>
@@ -7,6 +15,7 @@
 
 #include "konsolepanel.h"
 #include "common.h"
+#include "viewcontainer.h"
 
 KonsolePanel::KonsolePanel(QWidget *p) : ChatWindow( p )
 {
@@ -44,8 +53,8 @@ void KonsolePanel::childAdjustFocus()
 void KonsolePanel::partDestroyed()
 {
     k_part = 0;
-    // tell the main window to delete us
-    emit deleted(this);
+
+    emit closeView(this);
 }
 
 void KonsolePanel::konsoleChanged(const QString& /* data */)
