@@ -189,14 +189,26 @@ KonversationMainWindow::KonversationMainWindow() : KMainWindow(0,"main_window",
     }
     else
     {
-        action = new KAction(i18n("Move Tab Left"), "1leftarrow", KShortcut("Alt+Shift+Left"),
-            m_viewContainer, SLOT(moveViewLeft()), actionCollection(), "move_tab_left");
-        action->setEnabled(false);
-        action->setToolTip("Move this tab");
-        action = new KAction(i18n("Move Tab Right"), "1rightarrow", KShortcut("Alt+Shift+Right"),
-            m_viewContainer, SLOT(moveViewRight()), actionCollection(), "move_tab_right");
+        KAction* action2;
+        if (QApplication::reverseLayout())
+        {
+            action2 = new KAction(i18n("Move Tab Right"), "1rightarrow", KShortcut("Alt+Shift+Right"),
+                          m_viewContainer, SLOT(moveViewLeft()), actionCollection(), "move_tab_left");
+            action  = new KAction(i18n("Move Tab Left"), "1leftarrow", KShortcut("Alt+Shift+Left"),
+                          m_viewContainer, SLOT(moveViewRight()), actionCollection(), "move_tab_right");
+        }
+        else
+        {
+            action  = new KAction(i18n("Move Tab Left"), "1leftarrow", KShortcut("Alt+Shift+Left"),
+                          m_viewContainer, SLOT(moveViewLeft()), actionCollection(), "move_tab_left");
+                action2 = new KAction(i18n("Move Tab Right"), "1rightarrow", KShortcut("Alt+Shift+Right"),
+                          m_viewContainer, SLOT(moveViewRight()), actionCollection(), "move_tab_right");
+        }
+
         action->setEnabled(false);
         action->setToolTip("Move this tab");
+        action2->setEnabled(false);
+        action2->setToolTip("Move this tab");
     }
 
     action = new KToggleAction(i18n("Enable Notifications"), 0, 0, m_viewContainer, SLOT(toggleViewNotifications()), actionCollection(), "tab_notifications");
@@ -305,8 +317,28 @@ KonversationMainWindow::~KonversationMainWindow()
     Preferences::writeConfig();
 }
 
+int KonversationMainWindow::confirmQuit()
+{
+    KonversationApplication *konvApp=static_cast<KonversationApplication *>(kapp);
+
+    QPtrList<Server> serverList = konvApp->getServerList();
+    if (serverList.isEmpty()) return KMessageBox::Continue;
+
+    int result=KMessageBox::warningContinueCancel(
+        this,
+        i18n("<qt>Are you sure you want to quit <b>Konversation</b>?</qt>"),
+        i18n("Confirm Quit"),
+        i18n("Quit"),
+        "systemtrayquitKonversation");
+    return result;
+}
+
 void KonversationMainWindow::quitProgram()
 {
+    if (Preferences::showTrayIcon() &&
+        sender() != m_trayIcon &&
+        confirmQuit() == KMessageBox::Cancel) return;
+
     // will call queryClose()
     m_closeApp = true;
     close();
@@ -330,6 +362,9 @@ bool KonversationMainWindow::queryClose()
         return false;
     }
 
+    if (!Preferences::showTrayIcon() && confirmQuit() == KMessageBox::Cancel)
+        return false;
+
     m_viewContainer->silenceViews();
 
     // send quit to all servers
