@@ -22,6 +22,7 @@
 #include "linkaddressbook/addressbook.h"
 #include "linkaddressbook/linkaddressbookui.h"
 #include "konversationmainwindow.h"
+#include "viewcontainer.h"
 
 /*
   @author Gary Cramblitt
@@ -83,23 +84,14 @@ uint NickInfo::getNickColor()
     // do we already have a color?
     if(!m_nickColor)
     {
-        // get next color offset in line
-        uint& offset = KonversationApplication::instance()->getColorOffset();
+        int nickvalue = 0;
 
-        // wrap to first color if we reached the maximum index
-        if(offset >= 8)
-            offset=0;
-
-        // make sure we don't have the same color as the background
-        QString backgroundColor=Preferences::color(Preferences::TextViewBackground).name();
-        if(backgroundColor == Preferences::nickColor(offset).name() ) {
-            offset = (offset+1)%8;
+        for (uint index = 0; index < m_nickname.length(); index++)
+        {
+            nickvalue += m_nickname[index].unicode();
         }
 
-        // store color (+1 so we can check for 0 as "unassigned"
-        m_nickColor = offset + 1;
-        // move on color offset
-        ++offset;
+        m_nickColor = (nickvalue % 8) + 1;
     }
     // return color offset -1 (since we store it +1 for 0 checking)
     return m_nickColor-1;
@@ -354,7 +346,9 @@ void NickInfo::tooltipTableData(QTextStream &tooltip) const
     }
     else if(!getRealName().isEmpty() && getRealName().lower() != loweredNickname())
     {
-        tooltip << getRealName();
+        QString escapedRealName( getRealName() );
+        escapedRealName.replace("<","&lt;").replace(">","&gt;");
+        tooltip << escapedRealName;
         dirty = true;
     }
     else
@@ -420,7 +414,7 @@ void NickInfo::tooltipTableData(QTextStream &tooltip) const
 
 void NickInfo::showLinkAddressbookUI()
 {
-    LinkAddressbookUI *linkaddressbookui = new LinkAddressbookUI(m_owningServer->getMainWindow(), NULL, m_nickname, m_owningServer->getServerName(), m_owningServer->getServerGroup(), m_realName);
+    LinkAddressbookUI *linkaddressbookui = new LinkAddressbookUI(m_owningServer->getViewContainer()->getWindow(), NULL, m_nickname, m_owningServer->getServerName(), m_owningServer->getServerGroup(), m_realName);
     linkaddressbookui->show();
 
 }
