@@ -59,16 +59,16 @@ void NickListViewItem::refresh()
     Images* images = KonversationApplication::instance()->images();
     QPixmap icon;
 
-    if ( nick->isAdmin() )
-    {
-        flags += 128;
-        icon = images->getNickIcon( Images::Admin, away );
-    }
-    else if ( nick->isOwner() )
+    if ( nick->isOwner() )
     {
         flags += 64;
         icon = images->getNickIcon( Images::Owner, away );
     }
+    else if ( nick->isAdmin() )
+    {
+        flags += 128;
+        icon = images->getNickIcon( Images::Admin, away );
+    }
     else if ( nick->isOp() )
     {
         flags += 32;
@@ -129,11 +129,11 @@ QString NickListViewItem::calculateLabel1()
 
     if(!addressee.realName().isEmpty())           //if no addressee, realName will be empty
     {
-        return nick->getNickInfo()->getNickname() + " (" + addressee.realName() + ")";
+        return nick->getNickInfo()->getNickname() + " (" + addressee.realName() + ')';
     }
     else if(Preferences::showRealNames() && !nick->getNickInfo()->getRealName().isEmpty())
     {
-        return nick->getNickInfo()->getNickname() + " (" + nick->getNickInfo()->getRealName() + ")";
+        return nick->getNickInfo()->getNickname() + " (" + nick->getNickInfo()->getRealName() + ')';
     }
 
     return nick->getNickInfo()->getNickname();
