@@ -21,7 +21,7 @@
 #include "chatwindow.h"
 #include "konversationapplication.h"
 #include "konversationmainwindow.h"
-#include "popup.h"
+#include "viewcontainer.h"
 #include "trayicon.h"
 #include "server.h"
 
@@ -53,9 +53,7 @@ namespace Konversation
         QString cleanedMessage = QStyleSheet::escape(Konversation::removeIrcMarkup(message));
         QString cutup = addLineBreaks(cleanedMessage);
 
-        KNotifyClient::event(winId(), "message", QString("<qt>&lt;%1&gt; %2</qt>").arg(fromNick).arg(cutup));
-        //   Popup *pop = new Popup(m_mainWindow,chatWin,
-        //     QString("<qt>&lt;%2&gt; %3</qt>").arg(chatWin->getName()).arg(fromNick).arg(cutup));
+        KNotifyClient::event(m_mainWindow->winId(), "message", QString("<qt>&lt;%1&gt; %2</qt>").arg(fromNick).arg(cutup));
 
         if(!Preferences::trayNotifyOnlyOwnNick())
         {
@@ -63,10 +61,10 @@ namespace Konversation
         }
 
         if(Preferences::oSDShowChannel() &&
-            (!m_mainWindow->isActiveWindow() || (chatWin != m_mainWindow->frontView())))
+            (!m_mainWindow->isActiveWindow() || (chatWin != m_mainWindow->getViewContainer()->getFrontView())))
         {
             KonversationApplication* konvApp = static_cast<KonversationApplication*>(kapp);
-            konvApp->osd->showOSD("(" + chatWin->getName() + ") <" + fromNick + "> " + cleanedMessage);
+            konvApp->osd->showOSD('(' + chatWin->getName() + ") <" + fromNick + "> " + cleanedMessage);
         }
     }
 
@@ -85,9 +83,7 @@ namespace Konversation
         QString cleanedMessage = QStyleSheet::escape(Konversation::removeIrcMarkup(message));
         QString cutup = addLineBreaks(cleanedMessage);
 
-        KNotifyClient::event(winId(), "nick", QString("<qt>&lt;%1&gt; %2</qt>").arg(fromNick).arg(cutup));
-        //   Popup *pop = new Popup(m_mainWindow,chatWin,
-        //     QString("<qt>&lt;%2&gt; %3</qt>").arg(chatWin->getName()).arg(fromNick).arg(cutup));
+        KNotifyClient::event(m_mainWindow->winId(), "nick", QString("<qt>&lt;%1&gt; %2</qt>").arg(fromNick).arg(cutup));
 
         startTrayNotification(chatWin);
 
@@ -97,7 +93,7 @@ namespace Konversation
         {
             if((Preferences::oSDShowChannel() ||
                 Preferences::oSDShowOwnNick()) &&
-                (!m_mainWindow->isActiveWindow() || (chatWin != m_mainWindow->frontView())))
+                (!m_mainWindow->isActiveWindow() || (chatWin != m_mainWindow->getViewContainer()->getFrontView())))
             {
                 konvApp->osd->showOSD(i18n("[HighLight] (%1) <%2> %3").arg(chatWin->getName()).arg(fromNick).arg(cleanedMessage));
             }
@@ -105,7 +101,7 @@ namespace Konversation
         else if(chatWin->getType() == ChatWindow::Query)
         {
             if(Preferences::oSDShowQuery() &&
-                (!m_mainWindow->isActiveWindow() || (chatWin != m_mainWindow->frontView())))
+                (!m_mainWindow->isActiveWindow() || (chatWin != m_mainWindow->getViewContainer()->getFrontView())))
             {
                 konvApp->osd->showOSD(i18n("(Query) <%1> %2").arg(fromNick).arg(cleanedMessage));
             }
@@ -142,11 +138,11 @@ namespace Konversation
             return;
         }
 
-        KNotifyClient::event(winId(), "join", i18n("%1 joined %2").arg(nick, chatWin->getName()));
+        KNotifyClient::event(m_mainWindow->winId(), "join", i18n("%1 joined %2").arg(nick, chatWin->getName()));
 
         // OnScreen Message
         if(Preferences::oSDShowChannelEvent() &&
-            (!m_mainWindow->isActiveWindow() || (chatWin != m_mainWindow->frontView())))
+            (!m_mainWindow->isActiveWindow() || (chatWin != m_mainWindow->getViewContainer()->getFrontView())))
         {
             KonversationApplication* konvApp = static_cast<KonversationApplication*>(kapp);
             konvApp->osd->showOSD(i18n("%1 joined %2").arg(nick, chatWin->getName()));
@@ -165,27 +161,17 @@ namespace Konversation
             return;
         }
 
-        KNotifyClient::event(winId(), "part", i18n("%1 parted %2").arg(nick, chatWin->getName()));
+        KNotifyClient::event(m_mainWindow->winId(), "part", i18n("%1 parted %2").arg(nick, chatWin->getName()));
 
         // OnScreen Message
         if(Preferences::oSDShowChannelEvent() &&
-            (!m_mainWindow->isActiveWindow() || (chatWin != m_mainWindow->frontView())))
+            (!m_mainWindow->isActiveWindow() || (chatWin != m_mainWindow->getViewContainer()->getFrontView())))
         {
             KonversationApplication* konvApp = static_cast<KonversationApplication*>(kapp);
             konvApp->osd->showOSD(i18n("%1 parted %2").arg(nick, chatWin->getName()));
         }
     }
 
-    int NotificationHandler::winId() const
-    {
-        if(m_mainWindow->systemTrayIcon() && m_mainWindow->systemTrayIcon()->isShown())
-        {
-            return m_mainWindow->systemTrayIcon()->winId();
-        }
-
-        return m_mainWindow->winId();
-    }
-
     void NotificationHandler::quit(ChatWindow* chatWin, const QString& nick)
     {
         if(!chatWin || !chatWin->notificationsEnabled())
@@ -198,7 +184,7 @@ namespace Konversation
             return;
         }
 
-        KNotifyClient::event(winId(), "part", i18n("%1 quit %2").arg(nick, chatWin->getServer()->getServerName()));
+        KNotifyClient::event(m_mainWindow->winId(), "part", i18n("%1 quit %2").arg(nick, chatWin->getServer()->getServerName()));
     }
 
     void NotificationHandler::nickChange(ChatWindow* chatWin, const QString& oldNick, const QString& newNick)
@@ -213,7 +199,7 @@ namespace Konversation
             return;
         }
 
-        KNotifyClient::event(winId(), "nickchange", i18n("%1 changed nickname to %2").arg(oldNick, newNick));
+        KNotifyClient::event(m_mainWindow->winId(), "nickchange", i18n("%1 changed nickname to %2").arg(oldNick, newNick));
     }
 
     void NotificationHandler::dccIncoming(ChatWindow* chatWin, const QString& fromNick)
@@ -228,7 +214,7 @@ namespace Konversation
             return;
         }
 
-        KNotifyClient::event(winId(), "dcc_incoming", i18n("%1 wants to send a file to you").arg(fromNick));
+        KNotifyClient::event(m_mainWindow->winId(), "dcc_incoming", i18n("%1 wants to send a file to you").arg(fromNick));
     }
 
     void NotificationHandler::mode(ChatWindow* chatWin, const QString& /*nick*/)
@@ -243,7 +229,7 @@ namespace Konversation
             return;
         }
 
-        KNotifyClient::event(winId(), "mode");
+        KNotifyClient::event(m_mainWindow->winId(), "mode");
     }
 
     void NotificationHandler::query(ChatWindow* chatWin, const QString& fromNick)
@@ -260,7 +246,7 @@ namespace Konversation
 
         startTrayNotification(chatWin);
 
-        KNotifyClient::event(winId(), "query",
+        KNotifyClient::event(m_mainWindow->winId(), "query",
             i18n("%1 has started a conversation (query) with you.").arg(fromNick));
     }
 
@@ -276,7 +262,7 @@ namespace Konversation
             return;
         }
 
-        KNotifyClient::event(winId(), "notify",
+        KNotifyClient::event(m_mainWindow->winId(), "notify",
             i18n("%1 is online (%2).").arg(nick).arg(chatWin->getServer()->getServerName()));
     }
 
@@ -292,7 +278,7 @@ namespace Konversation
             return;
         }
 
-        KNotifyClient::event(winId(), "notify",
+        KNotifyClient::event(m_mainWindow->winId(), "notify",
             i18n("%1 went offline (%2).").arg(nick).arg(chatWin->getServer()->getServerName()));
     }
 
@@ -303,7 +289,7 @@ namespace Konversation
             return;
         }
 
-        KNotifyClient::event(winId(), "kick",
+        KNotifyClient::event(m_mainWindow->winId(), "kick",
             i18n("You are kicked by %1 from %2").arg(nick).arg(channel));
     }
 
@@ -314,7 +300,7 @@ namespace Konversation
             return;
         }
 
-        KNotifyClient::event(winId(), "dccChat",
+        KNotifyClient::event(m_mainWindow->winId(), "dccChat",
             i18n("%1 started a dcc chat with you").arg(nick));
     }
 
@@ -333,7 +319,7 @@ namespace Konversation
         startTrayNotification(chatWin);
 
         if(Preferences::oSDShowOwnNick() &&
-            (!m_mainWindow->isActiveWindow() || (chatWin != m_mainWindow->frontView())))
+            (!m_mainWindow->isActiveWindow() || (chatWin != m_mainWindow->getViewContainer()->getFrontView())))
         {
             KonversationApplication* konvApp = static_cast<KonversationApplication*>(kapp);
             // if there was no nick associated, this must be a command message, so don't try displaying
@@ -353,7 +339,7 @@ namespace Konversation
             return;
         }
 
-        KNotifyClient::event(winId(), "connectionFailure",
+        KNotifyClient::event(m_mainWindow->winId(), "connectionFailure",
             i18n("Failed to connect to %1").arg(server));
     }
 
@@ -369,7 +355,7 @@ namespace Konversation
             return;
         }
 
-        KNotifyClient::event(winId(), "channelJoin", i18n("You have joined %1.").arg(channel));
+        KNotifyClient::event(m_mainWindow->winId(), "channelJoin", i18n("You have joined %1.").arg(channel));
     }
 
     QString NotificationHandler::addLineBreaks(const QString& string)
