@@ -1,5 +1,3 @@
-// -*- mode: c++; c-file-style: "bsd"; c-basic-offset: 4; tabs-width: 4; indent-tabs-mode: nil -*-
-
 /*
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -67,10 +65,13 @@ namespace Konversation
         {
             // cut alias pattern from definition
             QString aliasPattern(aliasList[index].section(' ',0,0));
+            // cut first word from command line, so we do not wrongly find an alias
+            // that starts with the same letters, like /m would override /me
+            QString lineStart=line.section(' ',0,0);
 
             // pattern found?
             // TODO: cc may be a regexp character here ... we should escape it then
-            if(line.find(QRegExp('^'+cc+aliasPattern+"\\b"))!=-1)
+            if (lineStart==cc+aliasPattern)
             {
                 QString aliasReplace;
 
@@ -96,7 +97,7 @@ namespace Konversation
         return false;
     }
 
-    QStringList OutputFilter::splitForEncoding(QString inputLine, int MAX)
+    QStringList OutputFilter::splitForEncoding(const QString& inputLine, int MAX)
     {
         QString channelCodecName=Preferences::channelEncoding(m_server->getServerGroup(), destination);
 
@@ -332,7 +333,7 @@ namespace Konversation
             QStringList outputList=splitForEncoding(inputLine, m_server->getPreLength("PRIVMSG", destination));
             if (outputList.count() > 1)
             {
-                result.output=QString::null;
+                result.output=QString();
                 result.outputList=outputList;
                 for ( QStringList::Iterator it = outputList.begin(); it != outputList.end(); ++it )
                 {
@@ -389,15 +390,15 @@ namespace Konversation
         return changeMode(addNickToEmptyNickList(ownNick,parameter),'v','-');
     }
 
-    OutputFilterResult OutputFilter::parseJoin(QString channelName)
+    OutputFilterResult OutputFilter::parseJoin(QString& channelName)
     {
         OutputFilterResult result;
 
         if(channelName.contains(",")) // Protect against #foo,0 tricks
             channelName = channelName.remove(",0");
         //else if(channelName == "0") // FIXME IRC RFC 2812 section 3.2.1
-                        
-        if(channelName.isEmpty())
+
+        if (channelName.isEmpty())
         {
             result = usage(i18n("Usage: %1JOIN <channel> [password]").arg(commandChar));
         }
